==> apeman-bud-mock-3.0.1.tgz: package/lib/setup.js <==
/**
 * apeman bud for mock files.
 * @memberof module:apeman-bud-mock/lib
 * @function setup
 * @param {string} name - Name of mock page.
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

'use strict'

const argx = require('argx')
const pkg = require('../package.json')
const assert = require('assert')
const stringcase = require('stringcase')
const fs = require('fs')

const tmpls = {
  browser: 'browser.jsx.hbs',
  component: 'component.jsx.hbs',
  html: 'html.jsx.hbs'
}

/** @lends setup */
function setup (name, params) {
  let args = argx(arguments)
  name = args.shift('string')
  assert.ok(name, 'name is required.')
  params = args.shift('object') || {}
  let { type } = params
  assert.ok(type, 'type is required.')

  let snakeName = stringcase.snakecase(name)
  let tmpl = tmpls[ type ]
  if (!tmpl) {
    throw new Error(`Unknown type: ${type}`)
  }
  return {
    force: false,
    mode: '644',
    mkdirp: true,
    path: `${snakeName}.${type}.jsx`,
    tmpl: fs.readFileSync(`${__dirname}/../asset/${tmpl}`).toString(),
    data: {
      name,
      params,
      pkg,
      generator: 'coz',
      today: new Date().toLocaleDateString()
    }
  }
}

Object.assign(setup, {
  browser(name, params = {}) {
    return setup(name, Object.assign({ type: 'browser' }, params))
  },
  component(name, params = {}) {
    return setup(name, Object.assign({ type: 'component' }, params))
  },
  html(name, params = {}) {
    return setup(name, Object.assign({ type: 'html' }, params))
  }
})

module.exports = setup

==> apeman-bud-mock-4.0.0.tgz: package/lib/setup.js <==
/**
 * apeman bud for mock files.
 * @memberof module:apeman-bud-mock/lib
 * @function setup
 * @param {string} name - Name of mock page.
 * @param {object} params - Template params.
 * @returns {object} - Coz bud configuration.
 */

'use strict'

const argx = require('argx')
const pkg = require('../package.json')
const assert = require('assert')
const stringcase = require('stringcase')
const fs = require('fs')

const tmpls = {
  entrypoint: 'entrypoint.jsx.hbs',
  component: 'component.jsx.hbs',
  html: 'html.jsx.hbs'
}

/** @lends setup */
function setup (name, params) {
  let args = argx(arguments)
  name = args.shift('string')
  assert.ok(name, 'name is required.')
  params = args.shift('object') || {}
  let { type } = params
  type = String(type).trim()
  assert.ok(type, 'type is required.')
  let snakeName = stringcase.snakecase(name)
  let tmpl = tmpls[ type ]
  if (!tmpl) {
    throw new Error(`Unknown type: ${type}`)
  }
  return {
    force: false,
    mode: '644',
    mkdirp: true,
    path: `${snakeName}.${type}.jsx`,
    tmpl: fs.readFileSync(`${__dirname}/../asset/${tmpl}`).toString(),
    data: {
      name,
      params,
      pkg,
      generator: 'coz',
      today: new Date().toLocaleDateString()
    }
  }
}

Object.assign(setup, {
  entrypoint (name, params = {}) {
    return setup(name, Object.assign({ type: 'entrypoint' }, params))
  },
  component (name, params = {}) {
    return setup(name, Object.assign({ type: 'component' }, params))
  },
  html (name, params = {}) {
    return setup(name, Object.assign({ type: 'html' }, params))
  }
})

module.exports = setup
